@@ -15,7 +15,8 @@ from rest_framework.response import Response
 from data.forms.forms import HardwareForm, HardwareDHT22Form, HardwareMCP3008Form, HardwareModProbeForm, \
     HardwarePiPicoForm, HardwareVEML7700Form, HardwareTypeForm, ChannelForm, HardwareConfigForm, AccessoryForm, \
     CalibrationForm, CalibrationConstantForm, HubForm, HardwareIOTypeForm, SPIIoForm, PwmIoForm, SerialIoForm, \
-    I2cIoForm, DeviceFileIoForm, MCPAnalogIoForm, PiPicoACAnalogIoForm,PiPicoAnalogIoForm, PiGpioForm, HardwareIoForm, HardwarePMSA0031Form
+    I2cIoForm, DeviceFileIoForm, MCPAnalogIoForm, PiPicoACAnalogIoForm, PiPicoAnalogIoForm, PiGpioForm, HardwareIoForm, \
+    HardwarePMSA0031Form
 from data.models.models import Hardware, DHT22, MCP3008, ModProbe, PiPico, VEML7700, Accessory, Calibration, \
     CalibrationConstants, Channel, Hub, HardwareIO
 from data.serializers.serializers import HardwareSerializer, ChannelSerializer, AccessorySerializer, \
@@ -361,9 +362,11 @@ class HardwareViewSet(viewsets.ModelViewSet):
                 hardware.get_real_concrete_instance_class().delete()
             return HttpResponse(render(request, 'hardwares.html'))
 
-from data.forms.forms import DataTransformerForm,DataTransform
+
+from data.forms.forms import DataTransformerForm, DataTransform
 from data.models.models import DataTransformer
 
+
 class AccessoryViewSet(viewsets.ModelViewSet):
     queryset = Accessory.objects.all()
     serializer_class = AccessorySerializer
@@ -387,22 +390,22 @@ class AccessoryViewSet(viewsets.ModelViewSet):
         calibration_form = CalibrationForm(initial={'accessory': accessory})
 
         if accessory.has_data_transformer:
-            data_transformer = accessory.datatransformer
-            datatransformerset = formset_factory(DataTransform, formset=DataTransformerForm, extra=1)
-            formset = datatransformerset(initial=[data_transformer])
+            data_transformer = accessory.data_transformer
+            datatransformerset = formset_factory(DataTransform(instance=data_transformer), formset=DataTransformerForm, extra=0)
+            formset = datatransformerset(instance=data_transformer)
         else:
             data_transformer = DataTransformer()
             data_transformer.accessory = accessory
             data_transformer.save()
-            datatransformerset = formset_factory(DataTransform, formset=DataTransformerForm, extra=1)
-            formset = datatransformerset(initial=[])
-
-
-
+            accessory = Accessory.objects.get(**kwargs)
+            data_transformer = accessory.data_transformer
+            datatransformerset = formset_factory(DataTransform(instance=data_transformer), formset=DataTransformerForm, extra=0)
+            formset = datatransformerset(instance=data_transformer)
 
         if request.accepted_renderer.format == 'html':
             return Response(
-                {"accessory_form": accessory_form, "calibration_form": calibration_form, "calibrations": calibrations, "data_transformer_form":formset},
+                {"accessory_form": accessory_form, "calibration_form": calibration_form, "calibrations": calibrations,
+                 "data_transformer_form": formset},
                 template_name='accessory.html')
         else:
             return super(AccessoryViewSet, self).retrieve()
@@ -859,5 +862,3 @@ def listHubAccessories(request, hub_id):
     serialized_accessories = AccessorySerializer(many=True).to_representation(accessories)
 
     return JsonResponse(serialized_accessories, status=200, safe=False)
-
-
